@@ -29,7 +29,7 @@ from beeswarm.server.db.entities import Client, BaitSession, Session, Honeypot,
     Transcript
 from beeswarm.shared.helpers import send_zmq_request_socket
 from beeswarm.shared.message_enum import Messages
-
+from beeswarm.shared.socket_enum import SocketNames
 
 logger = logging.getLogger(__name__)
 
@@ -51,11 +51,14 @@ class SessionPersister(gevent.Greenlet):
 
         context = beeswarm.shared.zmq_context
         self.subscriber_sessions = context.socket(zmq.SUB)
-        self.subscriber_sessions.connect('inproc://sessionPublisher')
+        self.subscriber_sessions.connect(SocketNames.RAW_SESSIONS)
         self.subscriber_sessions.setsockopt(zmq.SUBSCRIBE, '')
 
+        self.processedSessionsPublisher = context.socket(zmq.PUB)
+        self.processedSessionsPublisher.bind(SocketNames.PROCESSED_SESSIONS)
+
         self.config_actor_socket = context.socket(zmq.REQ)
-        self.config_actor_socket.connect('inproc://configCommands')
+        self.config_actor_socket.connect(SocketNames.CONFIG_COMMANDS)
 
     def _run(self):
         poller = zmq.Poller()
@@ -202,10 +205,14 @@ class SessionPersister(gevent.Greenlet):
         db_session.add(bait_session)
         db_session.delete(honeypot_session)
         db_session.commit()
+        self.processedSessionsPublisher('{0} {1} {2}'.format(Messages.DELETED_DUE_TO_MERGE, honeypot_session.id,
+                                                             bait_session.id))
+        self.processedSessionsPublisher('{0} {1}'.format(Messages.SESSION,
+                                                         json.dumps(bait_session.to_dict())))
 
     def classify_malicious_sessions(self, delay_seconds=30):
         """
-        Will classify all unclassified sessions malicious activity.
+        Will classify all unclassified sessions as malicious activity.
 
         :param delay_seconds: no sessions newer than (now - delay_seconds) will be processed.
         """
@@ -252,8 +259,9 @@ class SessionPersister(gevent.Greenlet):
                 logger.debug('Classifying session with id {0} as bruteforce attempt.'.format(session.id))
                 session.classification = db_session.query(Classification).filter(
                     Classification.type == 'bruteforce').one()
-
-        db_session.commit()
+            db_session.commit()
+            self.processedSessionsPublisher('{0} {1}'.format(Messages.SESSION,
+                                                             json.dumps(session.to_dict())))
 
     def send_config_request(self, request):
         return send_zmq_request_socket(self.config_actor_socket, request)
